import CategoryImageList from "@/components/categories/CategoryImageList";
import prisma from "@/lib/prisma";

export default async function CategoriesSinglePage({ params }: { params: { id: string } }) {
  const { id } = await params;

  const category = await prisma.category.findUnique({
    where: {
      id,
    },
    include: {
      images: {
        select: {
          id: true,
          imageName: true,
          fileKey: true,
          nsfw: true,
          altText: true,
          album: {
            select: {
              slug: true,
              gallery: {
                select: {
                  slug: true,
                },
              },
            }
          }
        }
      }
    }
  });

  if (!category) {
    return (
      <div className="max-w-7xl mx-auto px-4 py-12 space-y-12">
        <h1 className="text-4xl font-bold tracking-tight">Category not found</h1>
      </div>
    )
  }

  return (
    <div className="max-w-7xl mx-auto px-4 py-12 space-y-12">
      {category && (
        <>
          <section className="text-center space-y-4">
            <h1 className="text-4xl font-bold tracking-tight">Category: {category.name}</h1>
            <p className="text-lg text-muted-foreground">
              {category.description}
            </p>
          </section>
          <CategoryImageList images={category.images} />
        </>
      )}
    </div>
  );
}