import { Album, Gallery, Image } from "@/generated/prisma";
import NextImage from "next/image";
import Link from "next/link";

type ImagesWithItems = (Pick<Image, "id" | "fileKey" | "imageName" | "altText" | "nsfw"> & {
  album?: (Pick<Album, "slug"> & {
    gallery?: Pick<Gallery, "slug"> | null
  }) | null
})[]

export default function CategoryImageList({ images }: { images: ImagesWithItems }) {
  return (
    <section>
      <h1 className="text-2xl font-bold mb-4">Images</h1>
      <div className="grid gap-6 sm:grid-cols-2 md:grid-cols-3 xl:grid-cols-4">
        {images ? images.map((img) => {
          const gallerySlug = img.album?.gallery?.slug;
          const albumSlug = img.album?.slug;
          if (!gallerySlug || !albumSlug || !img.id) return null;

          return (
            <Link href={`/${gallerySlug}/${albumSlug}/${img.id}`} key={img.id}>
              <div className="group rounded-lg border overflow-hidden hover:shadow-lg transition-shadow bg-background">
                <div className="relative aspect-[4/3] w-full bg-muted items-center justify-center">
                  {img.fileKey ? (
                    <NextImage
                      src={`/api/image/thumbnails/${img.fileKey}.webp`}
                      alt={img.altText || ""}
                      fill
                      className="object-cover"
                    />
                  ) : (
                    <div className="flex items-center justify-center h-full text-muted-foreground text-sm">
                      No cover image
                    </div>
                  )}
                </div>
                <div className="p-4">
                  <h2 className="text-lg font-semibold truncate text-center">{img.imageName}</h2>
                </div>
              </div>
            </Link>
          )
        }) : "There are no images here!"}
      </div>
    </section>
  );
}