import { Album, Image } from "@/generated/prisma";
import NextImage from "next/image";
import Link from "next/link";

type AlbumsWithItems = Album & {
  coverImage: Image | null;
}

export default function AlbumList({ albums, gallerySlug }: { albums: AlbumsWithItems[], gallerySlug: string }) {
  return (
    <section>
      <h1 className="text-2xl font-bold mb-4">Albums</h1>
      <div className="grid gap-6 sm:grid-cols-2 md:grid-cols-3 xl:grid-cols-4">
        {albums ? albums.map((album) => (
          <Link href={`/${gallerySlug}/${album.slug}`} key={album.id}>
            <div className="group rounded-lg border overflow-hidden hover:shadow-lg transition-shadow bg-background">
              <div className="relative aspect-[4/3] w-full bg-muted items-center justify-center">
                {album.coverImage?.fileKey ? (
                  <NextImage
                    src={`/api/image/thumbnails/${album.coverImage.fileKey}.webp`}
                    alt={album.coverImage.imageName}
                    fill
                    className="object-cover"
                  />
                ) : (
                  <div className="flex items-center justify-center h-full text-muted-foreground text-sm">
                    No cover image
                  </div>
                )}
              </div>
              <div className="p-4">
                <h2 className="text-lg font-semibold truncate text-center">{album.name}</h2>
              </div>
            </div>
          </Link>
        )) : "There are no albums here!"}
      </div>
    </section>
  );
}