import prisma from "@/lib/prisma";
import Image from "next/image";
import Link from "next/link";

export default async function GalleryList() {
  const galleries = await prisma.gallery.findMany({
    include: {
      coverImage: true
    }
  });

  return (
    <section>
      <h1 className="text-2xl font-bold mb-4">Galleries</h1>
      <div className="grid gap-6 sm:grid-cols-2 md:grid-cols-3 xl:grid-cols-4">
        {galleries ? galleries.map((gallery) => (
          <Link href={`/${gallery.slug}`} key={gallery.id}>
            <div className="group rounded-lg border overflow-hidden hover:shadow-lg transition-shadow bg-background">
              <div className="relative aspect-[4/3] w-full bg-muted">
                {gallery.coverImage?.fileKey ? (
                  <Image
                    src={`/api/image/thumbnails/${gallery.coverImage.fileKey}.webp`}
                    alt={gallery.coverImage.imageName}
                    fill
                    className="object-cover"
                  />
                ) : (
                  <div className="flex items-center justify-center h-full text-muted-foreground text-sm">
                    No cover image
                  </div>
                )}
              </div>
              <div className="p-4">
                <h2 className="text-lg font-semibold truncate text-center">{gallery.name}</h2>
              </div>
            </div>
          </Link>
        )) : "There are no galleries here!"}
      </div>
    </section>
  );
}