// components/images/ArtistInfoBox.tsx
"use client"

import { Artist, Social } from "@/generated/prisma"
import { getSocialIcon } from "@/utils/socialIconMap"
import { UserIcon } from "lucide-react"
import Link from "next/link"

type ArtistWithItems = Artist & {
  socials: Social[]
}

export default function ArtistInfoBox({ artist }: { artist: ArtistWithItems }) {
  return (
    <div className="border rounded-lg p-4 shadow bg-muted/30 w-full max-w-xl">
      <div className="flex items-center gap-3 mb-2">
        <UserIcon className="w-5 h-5 text-muted-foreground" />
        <Link href={`/artists/${artist.slug}`} className="font-semibold text-lg hover:underline">
          {artist.displayName}
        </Link>
      </div>

      {artist.socials?.length > 0 && (
        <div className="flex flex-col gap-3 flex-wrap mt-2">
          {artist.socials.map((social) => {
            const Icon = getSocialIcon(social.platform)
            return (
              <div key={social.id}>
                <a
                  href={social.link || ""}
                  target="_blank"
                  rel="noopener noreferrer"
                  className="flex items-center gap-1 text-sm text-muted-foreground hover:text-primary hover:underline"
                >
                  <Icon className="w-4 h-4" />
                  {social.platform}: {social.handle}
                  {social.isPrimary && (
                    <span className="text-xs text-primary font-semibold ml-1">(main)</span>
                  )}
                </a>
              </div>
            )
          })}
        </div>
      )}
    </div>
  )
}
