import { Image as ImageType } from "@/generated/prisma";
import Link from "next/link";
// import { SocialIcon } from "react-social-icons";

type Props = {
  image: ImageType & {
    artist?: {
      id: string;
      slug: string;
      displayName: string;
      socials?: { type: string; handle: string; link: string }[];
    };
    categories?: { id: string; name: string }[];
    tags?: { id: string; name: string }[];
    album?: { id: string; name: string; slug: string };
  };
};

export default function ImageInfoPanel({ image }: Props) {
  return (
    <div className="w-full max-w-2xl mt-8 border border-border rounded-lg p-6 shadow-sm bg-background">
      {/* Creator */}
      {image.artist && (
        <div className="mb-4">
          <h2 className="text-lg font-semibold mb-1">Creator</h2>
          <Link
            href={`/artists/${image.artist.slug}`}
            className="text-primary hover:underline font-medium"
          >
            {image.artist.displayName}
          </Link>

          {image.artist.socials?.length > 0 && (
            <div className="flex gap-2 mt-2">
              {image.artist.socials.map((social, i) => (
                <SocialIcon
                  key={i}
                  url={social.link}
                  target="_blank"
                  rel="noopener noreferrer"
                  style={{ height: 28, width: 28 }}
                  title={social.type}
                />
              ))}
            </div>
          )}
        </div>
      )}

      {/* Album */}
      {image.album && (
        <div className="mb-4">
          <h2 className="text-lg font-semibold mb-1">Album</h2>
          <Link
            href={`/galleries/${image.album.slug}`}
            className="text-primary hover:underline"
          >
            {image.album.name}
          </Link>
        </div>
      )}

      {/* Categories */}
      {image.categories?.length > 0 && (
        <div className="mb-4">
          <h2 className="text-lg font-semibold mb-1">Categories</h2>
          <div className="flex flex-wrap gap-2">
            {image.categories.map((cat) => (
              <Link
                key={cat.id}
                href={`/categories/${cat.id}`}
                className="bg-muted text-sm px-2 py-1 rounded hover:bg-accent"
              >
                {cat.name}
              </Link>
            ))}
          </div>
        </div>
      )}

      {/* Tags */}
      {image.tags?.length > 0 && (
        <div>
          <h2 className="text-lg font-semibold mb-1">Tags</h2>
          <div className="flex flex-wrap gap-2">
            {image.tags.map((tag) => (
              <Link
                key={tag.id}
                href={`/tags/${tag.id}`}
                className="bg-muted text-sm px-2 py-1 rounded hover:bg-accent"
              >
                #{tag.name}
              </Link>
            ))}
          </div>
        </div>
      )}
    </div>
  );
}
