// src/utils/generateBreadcrumbsFromPath.ts
import prisma from "@/lib/prisma";

export async function generateBreadcrumbsFromPath(segments: string[]) {
  const items: { name: string; href: string }[] = [];

  let galleryId: string | null = null;
  let accumulatedPath = "";

  for (const segment of segments) {
    accumulatedPath += `/${segment}`;

    // Try match gallery
    const gallery = await prisma.gallery.findUnique({ where: { slug: segment } });
    if (gallery) {
      items.push({ name: gallery.name, href: accumulatedPath });
      galleryId = gallery.id;
      continue;
    }

    // Try match album using compound key
    if (galleryId) {
      const album = await prisma.album.findUnique({
        where: {
          galleryId_slug: {
            galleryId,
            slug: segment,
          },
        },
      });
      if (album) {
        items.push({ name: album.name, href: accumulatedPath });
        continue;
      }
    }

    // Try match artist
    const artist = await prisma.artist.findUnique({ where: { slug: segment } });
    if (artist) {
      items.push({ name: artist.displayName, href: accumulatedPath });
      continue;
    }

    // Try match image
    const image = await prisma.image.findUnique({ where: { id: segment } });
    if (image) {
      items.push({ name: image.imageName, href: accumulatedPath });
      continue;
    }

    // Fallback: unknown segment
    items.push({ name: segment, href: accumulatedPath });
  }

  return items;
}
